# Datasets

## TTS Dataset

```{eval-rst}
.. autoclass:: TTS.tts.datasets.TTSDataset
    :members:
```

## Vocoder Dataset

```{eval-rst}
.. autoclass:: TTS.vocoder.datasets.gan_dataset.GANDataset
    :members:
```

```{eval-rst}
.. autoclass:: TTS.vocoder.datasets.wavegrad_dataset.WaveGradDataset
    :members:
```

```{eval-rst}
.. autoclass:: TTS.vocoder.datasets.wavernn_dataset.WaveRNNDataset
    :members:
```
